==> apache-geode-1.13.8-src.tgz: apache-geode-1.13.8-src/geode-core/src/main/java/org/apache/geode/internal/cache/persistence/DefaultDiskDirs.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.geode.internal.cache.persistence;

import static org.apache.geode.internal.lang.SystemPropertyHelper.DEFAULT_DISK_DIRS_PROPERTY;
import static org.apache.geode.internal.lang.SystemPropertyHelper.getProductStringProperty;

import java.io.File;
import java.util.Optional;

import org.apache.geode.annotations.Immutable;

public class DefaultDiskDirs {

  @Immutable
  private static final File[] DEFAULT_DISK_DIRS_VALUE = new File[] {new File(".")};

  public static File[] getDefaultDiskDirs() {
    Optional<String> value = getProductStringProperty(DEFAULT_DISK_DIRS_PROPERTY);
    if (value.isPresent()) {
      String diskDirs = value.get();
      return new File[] {new File(diskDirs)};
    } else {
      return DEFAULT_DISK_DIRS_VALUE.clone();
    }
  }
}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/geode-core/src/main/java/org/apache/geode/internal/cache/persistence/DefaultDiskDirs.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.geode.internal.cache.persistence;

import static org.apache.geode.internal.lang.SystemProperty.getProductStringProperty;
import static org.apache.geode.internal.lang.SystemPropertyHelper.DEFAULT_DISK_DIRS_PROPERTY;

import java.io.File;
import java.util.Optional;

import org.apache.geode.annotations.Immutable;

public class DefaultDiskDirs {

  @Immutable
  private static final File[] DEFAULT_DISK_DIRS_VALUE = new File[] {new File(".")};

  public static File[] getDefaultDiskDirs() {
    Optional<String> value = getProductStringProperty(DEFAULT_DISK_DIRS_PROPERTY);
    if (value.isPresent()) {
      String diskDirs = value.get();
      return new File[] {new File(diskDirs)};
    } else {
      return DEFAULT_DISK_DIRS_VALUE.clone();
    }
  }
}
